MappingSet
==========

.. currentmodule:: semra.struct

.. autoclass:: MappingSet
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~MappingSet.model_computed_fields
      ~MappingSet.model_config
      ~MappingSet.model_fields

   .. rubric:: Methods Summary

   .. autosummary::

      ~MappingSet.get_confidence
      ~MappingSet.key

   .. rubric:: Attributes Documentation

   .. autoattribute:: model_computed_fields
   .. autoattribute:: model_config
   .. autoattribute:: model_fields

   .. rubric:: Methods Documentation

   .. automethod:: get_confidence
   .. automethod:: key
